@@ -59,7 +59,10 @@ class SNScontent:
             self.content.append(content)
         elif type(content) == bytes:
             # could be encrypted content, by parsing we can find out
-            self.append(content.decode('utf-8'))
+            try:
+                self.append(content.decode('utf-8'))
+            except:
+                raise SNSobjectException(content, "Tried converted byte array to str, but this could not be done")
         elif type(content) == SNScontent:
             # somehow we got an SNScontent object, just unpack and add to this class
             self.append_list(content.content)
@@ -74,4 +77,4 @@ class SNScontent:
         return default
 
     def __str__(self):
-        return '\r\n\r\n'.join(['\r\n'.join([(key + ': ' + value) for key, value in item.items()]) for item in self.content]) 
\ No newline at end of file
+        return '\r\n\r\n'.join(['\r\n'.join([([key + ": " + e2 for e2 in value]).join('\r\n') for key, value in e1.items()]) for e1 in self.content]) 
\ No newline at end of file
